@@ -5,13 +5,12 @@ This module does not contain docstrings for the wrapped code, check Apple's
 documentation for details on how to use these functions.
 """
 
-import objc
 import sys
 
+import objc
 from libdispatch import _metadata
 from libdispatch._inlines import _inline_list_
 
-
 sys.modules["libdispatch"] = mod = objc.ObjCLazyModule(
     "libdispatch",
     None,
@@ -26,13 +25,13 @@ sys.modules["libdispatch"] = mod = objc.ObjCLazyModule(
     },
 )
 
-import libdispatch._libdispatch as _manual
+
+import libdispatch._libdispatch as _manual  # isort:skip # noqa: E402
 
 for nm in dir(_manual):
     if nm.startswith("__"):
         continue
     setattr(mod, nm, getattr(_manual, nm))
 
-import sys
 
 del sys.modules["libdispatch._metadata"]
