@@ -1,6 +1,6 @@
-from PyObjCTools.TestSupport import *
-
 import libdispatch
+import objc
+from PyObjCTools.TestSupport import TestCase, min_os_level
 
 
 class TestSourceAPI(TestCase):
@@ -21,7 +21,8 @@ class TestSourceAPI(TestCase):
             libdispatch.DISPATCH_SOURCE_TYPE_MACH_RECV, libdispatch.dispatch_source_t
         )
         self.assertIsInstance(
-            libdispatch.DISPATCH_SOURCE_TYPE_MEMORYPRESSURE, libdispatch.dispatch_source_t
+            libdispatch.DISPATCH_SOURCE_TYPE_MEMORYPRESSURE,
+            libdispatch.dispatch_source_t,
         )
         self.assertIsInstance(
             libdispatch.DISPATCH_SOURCE_TYPE_PROC, libdispatch.dispatch_source_t
@@ -161,7 +162,3 @@ class TestSourceAPI(TestCase):
         self.assertArgIsFunction(
             libdispatch.dispatch_source_set_registration_handler_f, 1, b"v^v", 1
         )
-
-
-if __name__ == "__main__":
-    main()
